==> nextcloud-app-bookmarks-1%3a0.16.2-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/bookmarks/l10n/ja.js <==
OC.L10N.register(
    "bookmarks",
    {
    "Bookmarks" : "ブックマーク",
    "Add a Bookmark" : "ブックマークを追加",
    "Add folder" : "フォルダを追加",
    "Select" : "選択",
    "Deselect" : "選択解除",
    "Details" : "詳細",
    "Delete" : "削除",
    "Saved" : "保存しました",
    "Date added" : "追加日",
    "Link" : "リンク",
    "Tags" : "タグ",
    "Description" : "説明",
    "No bookmarks here." : "ブックマークがありません。",
    "Favorites" : "お気に入り",
    "Settings" : "設定",
    "Bookmarklet" : "ブックマークレット",
    "Add to {instanceName} " : "{instanceName}に追加",
    "Recently added" : "最近追加",
    "Most visited" : "最も訪れた",
    "View mode" : "表示モード",
    "List view" : "リスト表示",
    "RSS Feed" : "RSS フィード",
    "Permanently remove all bookmarks from your account. There is no going back!" : "アカウントからすべてのブックマークを完全に削除します。 戻ることはありません！",
    "Delete all bookmarks" : "すべてのブックマークを削除",
    "Open details" : "詳細を開く",
    "An error occurred while trying to save the bookmark." : "ブックマークの保存中にエラーが発生しました。",
    "Error" : "エラー",
    "Uncategorized" : "未分類",
    "Import completed successfully." : "インポートに成功しました",
    "Do you really want to delete all your bookmarks?" : "本当にすべてのブックマークを削除しますか？",
    "Set tags" : "タグを設定",
    "Failed to import one bookmark, because: " : "ブックマークのインポートに失敗しました。原因:",
    "No file provided for import" : "インポート用に提供されたファイルがありません",
    "Unsupported file type for import" : "インポートにサポートされていないファイルタイプ",
    "A Bookmark manager for Nextcloud" : "Nextcloud のブックマークマネージャー",
    "Add a bookmark" : "ブックマークを追加",
    "This URL is already bookmarked! Overwrite?" : "このURLはすでにブックマークされています! 上書きしますか?",
    "The title of the page" : "ページのタイトル",
    "The address of the page" : "ページのアドレス",
    "Description of the page" : "ページの説明",
    "Save" : "保存",
    "Previews" : "プレビュー",
    "In order to display real screenshots of your bookmarked websites, Bookmarks can use a third-party service to generate those." : "ブックマークされたウェブサイトの実際のスクリーンショットを表示するために、ブックマークはそれらを生成するためにサードパーティのサービスを使用することができます。",
    "Screenly API URL" : "Screenly API URL",
    "Screenly API key" : "Screenly API key",
    "Bookmarks feed" : "ブックマークフィード"
},
"nplurals=1; plural=0;");

==> nextcloud-app-bookmarks-1%3a1.1.0-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/bookmarks/l10n/ja.js <==
OC.L10N.register(
    "bookmarks",
    {
    "Bookmarks" : "ブックマーク",
    "Add a Bookmark" : "ブックマークを追加",
    "Add folder" : "フォルダーを追加",
    "Select" : "選択",
    "Deselect" : "選択解除",
    "Details" : "詳細",
    "Delete" : "削除",
    "Saved" : "保存しました",
    "Date added" : "追加日",
    "Link" : "リンク",
    "Tags" : "タグ",
    "Description" : "説明",
    "No bookmarks here." : "ブックマークがありません。",
    "Favorites" : "お気に入り",
    "Settings" : "設定",
    "Bookmarklet" : "ブックマークレット",
    "Add to {instanceName} " : "{instanceName}に追加",
    "Recently added" : "最近追加",
    "Most visited" : "最も訪れた",
    "View mode" : "表示モード",
    "List view" : "リスト表示",
    "RSS Feed" : "RSS フィード",
    "Permanently remove all bookmarks from your account. There is no going back!" : "アカウントからすべてのブックマークを完全に削除します。 戻ることはありません！",
    "Delete all bookmarks" : "すべてのブックマークを削除",
    "Open details" : "詳細を開く",
    "An error occurred while trying to save the bookmark." : "ブックマークの保存中にエラーが発生しました。",
    "Error" : "エラー",
    "Uncategorized" : "未分類",
    "Error parsing the import result" : "インポート結果の解析中にエラーが発生しました",
    "Import completed successfully." : "インポートに成功しました",
    "Do you really want to delete all your bookmarks?" : "本当にすべてのブックマークを削除しますか？",
    "Set tags" : "タグを設定",
    "Not allowed to access folder to import into" : "インポート先フォルダへのアクセスが許可されていません",
    "Failed to import one bookmark, because: " : "ブックマークのインポートに失敗しました。原因:",
    "No file provided for import" : "インポート用に提供されたファイルがありません",
    "Unsupported file type for import" : "インポートにサポートされていないファイルタイプ",
    "A Bookmark manager for Nextcloud" : "Nextcloud のブックマークマネージャー",
    "This app allows you to store and organize your favorite places on the web in one spot, while allowing you to sync them with your various devices and browsers.\nCheck out the third-party clients listed here: https://github.com/nextcloud/bookmarks#third-party-clients" : "このアプリでは、Web上のお気に入りの場所を一カ所で保存・整理し、さらに各種のデバイスやブラウザーと同期することができます。\nこちらに掲載されたサードパーティのクライアントをチェックしてください: https://github.com/nextcloud/bookmarks#third-party-clients",
    "Add a bookmark" : "ブックマークを追加",
    "This URL is already bookmarked! Overwrite?" : "このURLはすでにブックマークされています! 上書きしますか?",
    "The title of the page" : "ページのタイトル",
    "The address of the page" : "ページのアドレス",
    "Description of the page" : "ページの説明",
    "Save" : "保存",
    "Previews" : "プレビュー",
    "In order to display real screenshots of your bookmarked websites, Bookmarks can use a third-party service to generate those." : "ブックマークされたウェブサイトの実際のスクリーンショットを表示するために、ブックマークはそれらを生成するためにサードパーティのサービスを使用することができます。",
    "You can either sign up for free at <a href=\"http://screeenly.com\">screeenly.com</a> or <a href=\"https://github.com/stefanzweifel/screeenly\">setup your own server</a>." : "<a href=\"http://screeenly.com\">screeenly.com</a>で無料でサインアップすることも、<a href=\"https://github.com/stefanzweifel/screeenly\">自分のサーバーをセットアップ</a>することもできます。",
    "Screeenly API URL" : "Screeenly API URL",
    "Screeenly API key" : "Screeenly API キー",
    "Bookmarks feed" : "ブックマークフィード"
},
"nplurals=1; plural=0;");
